@@ -195,10 +195,7 @@ class Civilization : IsPartOfGameInfoSerialization {
     var lastSeenImprovement = HashMapVector2<String>()
 
     // To correctly determine "game over" condition as clarified in #4707
-    // Nullable type meant to be deprecated and converted to non-nullable,
-    // default false once we no longer want legacy save-game compatibility
-    // This parameter means they owned THEIR OWN capital btw, not other civs'.
-    var hasEverOwnedOriginalCapital: Boolean? = null
+    var hasEverOwnedOriginalCapital: Boolean = false
 
     val passableImpassables = HashSet<String>() // For Carthage-like uniques
 
