@@ -132,7 +132,7 @@ class RulesetValidator(val ruleset: Ruleset) {
         val vanillaRuleset = RulesetCache.getVanillaRuleset()  // for UnitTypes fallback
 
 
-        if (ruleset.units.values.none { it.hasUnique(UniqueType.FoundCity) })
+        if (ruleset.units.values.none { it.hasUnique(UniqueType.FoundCity, StateForConditionals.IgnoreConditionals) })
             lines += "No city-founding units in ruleset!"
 
         for (unit in ruleset.units.values) {
@@ -413,11 +413,6 @@ class RulesetValidator(val ruleset: Ruleset) {
             }
         }
 
-        @Suppress("DEPRECATION")
-        if (ruleset.modOptions.maxXPfromBarbarians != 30) {
-            lines.add("maxXPfromBarbarians is moved to the constants object, instead use: \nconstants: {\n    maxXPfromBarbarians: ${ruleset.modOptions.maxXPfromBarbarians},\n}", RulesetErrorSeverity.Warning)
-        }
-
         return lines
     }
 
